# Weights

0 Reserved: Heading
1 - 10 Reserved: Base
11 - 20 Free
21 - 30 Reserved: ARGS
31 - 40 Free
41 - 50 Reserved: ENV
51 - 60 Free
61 - 70 Reserved: User setup
71 - 80 Free
81 - 90 Reserved: Core APT package installation
91 - 100 Free
101 - 110 Reserved: Rust setup
111 - 120 Free
121 - 130 Reserved: Extra APT sources
131 - 140 Free
141 - 150 Reserved: APT package installation
151 - 160 Free
161 - 170 Reserved: PIP package installation
171 - 180 Free
181 - 190 Reserved: Content Copy
191 - 200 Free
201 - 240 Reserved: User scripts
241 - 250 Free
251 - 260 Reserved: Services
1001 - 1010 Known: JupyterLab Pack
1021 - 1030 Known: XFCE4 Pack
1041 - 1050 Known: CodeServer Pack
2001 - 2000 Recommended: User scripts
9001 - 10000 Reserved: Run CMDs

## Startup / Shutdown scripts
0 - 100: Reserved: System
101 - 200: Known: Packs
201 - 1000: Free
